@@ -39,6 +39,7 @@ from lino.core.tables import VentilatingTable
 
 from lino.core.actions import action
 from lino.core.actions import Action
+from lino.core.actions import WrappedAction
 from lino.core.actions import MultipleRowAction
 from lino.core.actions import ShowSlaveTable
 
@@ -73,6 +74,7 @@ from lino.core.fields import HtmlBox, PriceField, RichTextField
 
 from lino.core.fields import DisplayField, displayfield, htmlbox
 from lino.core.fields import VirtualField, virtualfield
+from lino.core.fields import VirtualBooleanField
 from lino.core.fields import RequestField, requestfield
 from lino.core.fields import Constant, constant
 from lino.core.fields import ForeignKey, OneToOneField
@@ -166,6 +168,7 @@ is_installed = settings.SITE.is_installed
 # get_db_overview_rst = settings.SITE.get_db_overview_rst
 add_welcome_handler = settings.SITE.add_welcome_handler
 build_media_url = settings.SITE.build_media_url
+build_site_cache_url = settings.SITE.build_site_cache_url
 build_static_url = settings.SITE.build_static_url
 get_default_language = settings.SITE.get_default_language
 get_language_info = settings.SITE.get_language_info
