@@ -40,6 +40,8 @@ from lino.core.site import html2text
 
 from lino.core.menus import Menu
 from lino.core.actions import ShowTable
+from lino.core.actions import register_params
+from lino.core.layouts import BaseLayout
 
 test_client = Client()
 # naming it simply "client" caused conflict with a
@@ -289,6 +291,8 @@ def fields_help(model, fieldnames=None, columns=False, all=None):
         else:
             get_field = model.parameters.get
             if fieldnames is None:
+                if not isinstance(model.params_layout, BaseLayout):
+                    register_params(model)
                 fieldnames = model.params_layout.main
     if fieldnames is None:
         return
