@@ -10,8 +10,8 @@ models = settings.SITE.models
 """
 
 from lino.core.exceptions import ChangedAPI
-actors = modules = ChangedAPI(
-    "Replace rt.modules and rt.actors by rt.models")
+# actors = modules = ChangedAPI(
+#     "Replace rt.modules and rt.actors by rt.models")
 
 # actors = settings.SITE.models
 
