@@ -20,8 +20,8 @@ copyright = '2019-2021 Rumma & Ko Ltd'
 htmlhelp_basename = 'help'
 extensions += ['lino.sphinxcontrib.logo']
 
-from atelier.sphinxconf import interproject
-interproject.configure(globals())
+# from atelier.sphinxconf import interproject
+# interproject.configure(globals())
 
 {% else %}
 
