@@ -11,7 +11,6 @@ import logging; logger = logging.getLogger(__name__)
 
 from django.utils.translation import gettext_lazy as _
 from django.utils.translation import gettext
-from django.utils.translation import get_language
 from django.utils.text import format_lazy
 from django.utils.encoding import force_str
 from django.conf import settings
@@ -295,6 +294,21 @@ class Action(Parametrizable, Permittable):
     callable to be called without arguments. That callable must have
     been defined in a :attr:`lino.core.plugin.Plugin.site_js_snippets`
     of the plugin.
+
+    Also can be defined as a class method, that takes the actor as the only
+    argument and should return a JavaScript runnable wrapped inside a function.
+    An example use case is defined in
+    :class:`lino.modlib.help.models.OpenHelpWindow` where the return string
+    follows the format::
+
+        return "() => window.open('URL')"
+
+    Callable Example::
+
+        def js_handler(self, actor):
+            ...
+            return JS_RUNABLE_INSIDE_A_WRAPPER_FUNCTION
+
     """
 
     action_name = None
@@ -317,10 +331,10 @@ class Action(Parametrizable, Permittable):
     See :attr:`lino.core.utils.Parametrizable.parameters`.
     """
 
-    key = None
+    hotkey = None
     """
-    Not used. The keyboard hotkey to associate to this action in a
-    user interface.
+    An instance of :class:`lino.core.keyboard.Hotkey`. Used as a keyboard
+    shortcut to trigger actions.
     """
 
     default_format = 'html'
@@ -756,9 +770,10 @@ class Action(Parametrizable, Permittable):
 
 
 class TableAction(Action):
+    pass
 
-    def get_action_title(self, ar):
-        return ar.get_title()
+    # def get_action_title(self, ar):
+    #     return ar.get_title()
 
 
 # class RedirectAction(Action):
@@ -782,6 +797,7 @@ class ShowTable(TableAction):
     def get_window_layout(self, actor):
         # ~ return self.actor.list_layout
         return None
+        # return actor.card_layout or actor.item_layout  # 20210910
 
     def get_window_size(self, actor):
         return actor.window_size
@@ -804,6 +820,10 @@ class ShowDetail(Action):
         self.owner = dl
         super(ShowDetail, self).__init__(label, **kwargs)
 
+    def attach_to_actor(self, actor, name):
+        self.help_text = _("Open a detail window on records of " + actor.app_label + ".")
+        return super().attach_to_actor(actor, name)
+
     def get_required_roles(self, actor):
         if self.owner.required_roles is None:
             return actor.required_roles
@@ -875,7 +895,7 @@ class ShowInsert(TableAction):
     sort_index = 10
     # required_roles = set([SiteUser])
     action_name = 'insert'
-    key = keyboard.INSERT  # (ctrl=True)
+    hotkey = keyboard.INSERT  # (ctrl=True)
     hide_virtual_fields = True
     # readonly = False
     select_rows = False
@@ -1178,7 +1198,16 @@ class ShowSlaveTable(Action):
         ar.set_response(eval_js=js)
 
 
-class QuickLinkAction(Action):
+class WrappedAction(Action):
+    """
+
+    On instantiation it takes a :class:`BoundAction
+    <lino.core.boundaction.BoundAction>` as a positional argument and returns an
+    action instance that behaves as a wrapper around the given
+    *BoundAction.action* useful when binding to another :class:`Actor
+    <lino.core.actors.Actor>`.
+
+    """
 
     instance = None  # for Renderer.menu_item_button()
     show_in_bbar = True
@@ -1189,11 +1218,12 @@ class QuickLinkAction(Action):
 
     def __init__(self, bound_action, **kwargs):
         self.bound_action = bound_action
-        kwargs.update(action_name=str(bound_action.actor)+'_'+bound_action.action.action_name)
+        kwargs.update(action_name=(str(bound_action.actor).replace('.', '_') +
+            '_' + bound_action.action.action_name))
         for k in self.WRAPPED_ATTRS:
             if k not in kwargs:
                 kwargs[k] = getattr(bound_action.action, k)
-        super(QuickLinkAction, self).__init__(**kwargs)
+        super(WrappedAction, self).__init__(**kwargs)
 
     def get_required_roles(self, actor):
         # print(self.bound_action, actor.required_roles | self.bound_action.required)
@@ -1264,7 +1294,7 @@ class DeleteSelected(MultipleRowAction):
     # ~ needs_selection = True
     label = _("Delete")
     # ~ url_action_name = 'delete'
-    key = keyboard.DELETE  # (ctrl=True)
+    hotkey = keyboard.DELETE  # (ctrl=True)
 
     # ~ client_side = True
 
@@ -1353,26 +1383,3 @@ def get_view_permission(e):
             return False  # bug 3 (bcss_summary) blog/2012/0927
         parent = parent.parent
     return True
-
-
-class OpenHelpWindow(Action):
-
-    action_name = 'open_help'
-    # icon_name = 'help'
-    button_text = '?'
-
-    def run_from_ui(self, ar, **kwargs):
-        # print("20210612")
-        parts = ['cache', 'help']
-        if get_language() != settings.SITE.DEFAULT_LANGUAGE.django_code:
-            parts.append(get_language())
-        parts.append(str(ar.actor) + ".html")
-        # parts.append("index.html")
-        ar.success(open_url=settings.SITE.build_media_url(*parts))
-
-    # def get_a_href_target(self):
-    #     parts = ['cache', 'help']
-    #     if get_language() != settings.SITE.DEFAULT_LANGUAGE.django_code:
-    #         parts.append(get_language())
-    #     parts.append("index.html")
-    #     return settings.SITE.build_media_url(*parts)
