@@ -304,8 +304,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     The :term:`application developer` can specify either the model class itself
     or a string of type ``'app.Model'``.
 
-    This should be `None` on all tables that are not subclass of
-    :class:`lino.core.dbtables.Table`.
+    If this is not `None`, it should be a subclass of
+    :class:`lino.core.fields.TableRow`.
 
     """
 
@@ -326,11 +326,9 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     Note that this attribute is not inherited from base classes.
 
-    :func:`lino.core.table.table_factory` also uses this.
+    :func:`lino.core.dbtables.table_factory` also uses this.
     """
 
-    open_help = actions.OpenHelpWindow()
-
     master = None
     """The class of the "master" for this actor.
 
@@ -458,7 +456,6 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     insert_layout = None
     card_layout = None
     item_layout = None
-    # item_layout = "overview"
 
     detail_template = None    # deprecated: use insert_layout instead
     insert_template = None    # deprecated: use detail_layout instead
@@ -537,15 +534,6 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         """
         return None
 
-    @classmethod
-    def get_actions_hotkeys(cls):
-        """
-        Return or yield a list of hotkeys to be linked to named actions.
-
-        [{'key': key, 'ctrl': Bool, 'shift': Bool, 'ba': action_name}]
-
-        """
-
     @classmethod
     def get_row_by_pk(self, ar, pk):
         """Return the data row identified by the given primary key.
@@ -772,6 +760,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     def init_layouts(cls):
         # 20200430 this was previously part of class_init, but is now called in
         # a second loop. Because calview.EventsParams copies parameters from Events.
+
         actions.install_layout(cls, 'detail_layout', layouts.DetailLayout)
         actions.install_layout(cls, 'insert_layout', layouts.InsertLayout,
             window_size=(cls.insert_layout_width, 'auto'))
@@ -1645,7 +1634,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         if len(s) == 1:
             m = settings.SITE.models.get(self.app_label)
             if m is None:
-                raise Exception("No plugin %s" % self.app_label)
+                raise Exception("No plugin {} ({}.{})".format(self.app_label, self, name))
                 # return None
             rpt = getattr(m, name, None)
             # if rpt is None and name != name.lower():
