@@ -1,4 +1,4 @@
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -24,6 +24,7 @@ from lino.core import actions
 from lino.core.model import Model
 from lino.core import actors
 from lino.core import constants
+from lino.core.requests import ActionRequest
 
 from lino.core.choicelists import ChoiceListField
 from .utils import models_by_base
@@ -176,8 +177,8 @@ class Table(AbstractTable):
     """
 
     use_as_default_table = True
-    """ Set this to `False` if this Table should *not* become the
-    Model's default table.
+    """Set this to `False` if this actor should *not* become the
+    model's default table.
 
     """
 
@@ -199,6 +200,20 @@ class Table(AbstractTable):
     """If True will position the quick search input to the bottom of the header and have it full width.
     Default: False"""
 
+    @classmethod
+    def init_layouts(cls):
+        # if cls.item_layout is None:
+        if cls.model is not None and issubclass(cls.model, Model):
+            if not cls.abstract:
+                for tbl in cls.__mro__:
+                    # print("20210629", tbl)
+                    if 'item_layout' in tbl.__dict__:
+                        break
+                    if tbl == actors.Actor:
+                        cls.item_layout = 'list_item'
+                        break
+        super(Table, cls).init_layouts()
+
     @classmethod
     def add_quick_search_filter(cls, qs, search_text):
         """Add a filter to the given queryset `qs` in order to apply a quick
@@ -281,8 +296,16 @@ class Table(AbstractTable):
         # return cls.model._meta.get_field(name)
 
     @classmethod
-    def get_actions_hotkeys(cls):
-        return cls.model.get_actions_hotkeys()
+    def as_story(cls, obj, ar):
+        if isinstance(ar, ActionRequest):
+            ar = cls.request(master_instance=ar)
+        rows = ar.selected_rows or ar.sliced_data_iterator
+        html = ""
+        # meta = []
+        for obj in rows:
+            html += obj.as_summary_row(ar)
+            # meta.append({'id': obj.pk})
+        return html#, meta
 
     @classmethod
     def get_pk_field(self):
@@ -414,8 +437,11 @@ class Table(AbstractTable):
                     # assert direct
                     # assert not m2m
                     if fk is None:
-                        candidates = ', '.join(
-                            [f.name for f in self.model._meta.get_fields()])
+                        if hasattr(self.model, '_meta'):
+                            candidates = ', '.join(
+                                [f.name for f in self.model._meta.get_fields()])
+                        else:
+                            candidates = "N/A"
                         raise Exception(
                             "Invalid master_key '{}' for {} ({} has fields {})".format(
                                 self.master_key, self, self.model, candidates))
