@@ -675,6 +675,24 @@ class VirtualField(FakeField):
         return sql, params
 
 
+class VirtualBooleanField(VirtualField):
+
+    """An editable virtual boolean field."""
+    editable = True
+
+    def __init__(self, ref_attr, label=None, **kw):
+        self.ref_attr = ref_attr
+        return_type = models.BooleanField(label)
+        VirtualField.__init__(self, return_type, None, **kw)
+
+    def set_value_in_object(self, request, obj, value):
+        if value is not None:
+            setattr(obj, self.ref_attr, value)
+
+    def value_from_object(self, obj, ar):
+        return getattr(obj, self.ref_attr)
+
+
 def virtualfield(return_type, **kwargs):
     """
     Decorator to turn a method into a :class:`VirtualField`.
@@ -686,13 +704,14 @@ def virtualfield(return_type, **kwargs):
     return decorator
 
 
-class Constant(object):
+class Constant(FakeField):
     """
     Deserves more documentation.
     """
 
-    def __init__(self, text_fn):
+    def __init__(self, text_fn, **kwargs):
         self.text_fn = text_fn
+        super().__init__(**kwargs)
 
 def constant():
     """
@@ -950,7 +969,7 @@ class DummyField(FakeField):
     #     self.name = name
 
     def __str__(self):
-        return self.name
+        return self.name or "unnamed DummyField"
 
     def __get__(self, instance, owner):
         if instance is None:
@@ -1048,6 +1067,7 @@ class TableRow(object):
 
     """
 
+
     @classmethod
     def setup_parameters(cls, params):
         """Inheritable hook for defining parameters for every actor on this model.
@@ -1172,6 +1192,13 @@ class TableRow(object):
             return ''
         return E.div(*forcetext(self.get_overview_elems(ar)))
 
+    @htmlbox()
+    def list_item(self, ar):
+        if ar is None:
+            return str(self)
+        return ar.obj2html(self)
+        # return E.div(*forcetext(self.get_overview_elems(ar)))
+
     def get_overview_elems(self, ar):
         # return [ar.obj2html(self)]
         return [self.obj2href(ar)]
@@ -1342,6 +1369,11 @@ def make_remote_field(model, name):
             #     "Invalid RemoteField %s.%s (no field %s in %s)" %
             #     (full_model_name(model), name, n, full_model_name(model)))
 
+        if isinstance(fld, DummyField):
+            # a remote field containing at least one dummy field is itself a
+            # dummy field
+            return fld
+
         # make sure that the atomizer gets created.
         store.get_atomizer(model, fld, fld.name)
 
