@@ -72,11 +72,10 @@ class Model(models.Model, fields.TableRow):
 
     active_fields = frozenset()
     """Deprecated. If specified, this is the default value for
-    :attr:`active_fields<lino.core.tables.AbstractTable.active_fields>`
+    :attr:`active_fields <lino.core.tables.AbstractTable.active_fields>`
     of every `Table` on this model.
 
     """
-
     hidden_elements = frozenset()
 
     # simple_parameters = frozenset()
@@ -555,6 +554,9 @@ class Model(models.Model, fields.TableRow):
         pass
 
     def as_summary_row(self, ar):
+        # used by tickets.Tickets table in the bootstrap frontend
+        # also when display_mode = constants.DISPLAY_MODE_STORY it returns html
+        # text for the object that is calling
         if self.summary_row_template:
             # not tested
             env = settings.SITE.plugins.jinja.renderer.jinja_env
@@ -755,15 +757,6 @@ class Model(models.Model, fields.TableRow):
         raise Exception(
             "Cannot resolve stateset specifier {!r}".format(states))
 
-    @classmethod
-    def get_actions_hotkeys(cls):
-        """
-        Return or yield a list of hotkeys to be linked to named actions.
-
-        [{'key': key, 'ctrl': Bool, 'shift': Bool, 'ba': action_name}]
-
-        """
-
     @classmethod
     def add_picker(model, fldname):
         """Add a picker for the named choicelist field.
@@ -955,7 +948,6 @@ LINO_MODEL_ATTRIBS = (
     'get_default_table',
     'get_default_table',
     'get_layout_aliases',
-    'get_actions_hotkeys',
     'as_summary_row',
     'summary_row_template',
     'get_related_project',
