@@ -275,6 +275,22 @@ class Plugin(object):
         """
         pass
 
+    def before_actors_discover(self):
+        """
+
+        This is called exactly once during :term:`site startup`, when models are
+        ready.  Used by `lino.modlib.help`
+
+        """
+        pass
+
+    # def after_discover(self):
+    #     """
+    #     This is called exactly once during startup, when actors have been
+    #     discovered. Needed by :mod:`lino.modlib.help`.
+    #     """
+    #     pass
+
     def post_site_startup(self, site):
         """
         This will be called exactly once, when models are ready.
