@@ -91,7 +91,7 @@ class Renderer(object):
     not_implemented_js = None
     extjs_version = None
 
-    hide_dashboard_items = False
+    support_dashboard_layout = False
     """Don't show dashboard items when rendering :xfile:`admin_main.html`.
 
     """
@@ -124,6 +124,13 @@ class Renderer(object):
         """
         return json_response(ar.response, ar.content_type)
 
+    def get_action_params(self, ar, ba, obj, **kwargs):
+        if ba.action.parameters:
+            fv = ba.action.params_layout.params_store.pv2list(
+                ar, ar.action_param_values)
+            kwargs[constants.URL_PARAM_FIELD_VALUES] = fv
+        return kwargs
+
     # def render_action_response(self, ar):
     #     """In a plain HTML UI this will return a full HTML index page, in
     #     ExtJS it will return JSON code.
@@ -161,7 +168,7 @@ class HtmlRenderer(Renderer):
         return ''.join([
             tostring(e) for e in self.table2story(*args, **kwargs)])
 
-    def show_detail(self, ar, *args, **kwargs):
+    def show_detail(self, ar, obj, display_mode=None, **kwargs):
         """Show the window that is to be opened by `ar`.
 
         The output is currently gives no beautiful representation of the window,
@@ -171,12 +178,21 @@ class HtmlRenderer(Renderer):
         """
         from bs4 import BeautifulSoup
         import rstgen
-        lh = ar.bound_action.get_layout_handel()
+        if display_mode == constants.DISPLAY_MODE_CARDS:
+            layout = ar.actor.card_layout or actor.item_layout
+            lh = layout.get_layout_handle()
+        else:
+            lh = ar.bound_action.get_layout_handel()
+            # layout = ar.actor.detail_layout
         # print("20210615 show_detail()", ar.bound_action, lh.layout)
-        obj = None
-        if ar.bound_action.action.select_rows:
-            if len(ar.selected_rows) > 0:
-                obj = ar.selected_rows[0]
+        # return
+        # obj = None
+        # if ar.bound_action.action.select_rows:
+        #     rows = ar.selected_rows
+        # else:
+        #     rows = ar.sliced_data_iterator
+        #     # if len(ar.selected_rows) > 0:
+        #     #     obj = ar.selected_rows[0]
         chunks = []
 
         def tag2rst(t, level=1):
@@ -261,17 +277,19 @@ class HtmlRenderer(Renderer):
         """
         return self.not_implemented_js
 
-    def instance_handler(self, ar, obj, ba):
+    def instance_handler(self, ar, obj, ba, **status):
         """
         Return a string of Javascript code which would open a detail window
         on the given database object.
         """
+        status.update(record_id=obj.pk)
+
         if ba is None:
             ba = obj.get_detail_action(ar)
         # ba = obj.__class__.get_default_table().detail_action
         # print(20180831, ba.get_view_permission(ar.get_user().user_type))
         if ba is not None:
-            return self.action_call(ar, ba, dict(record_id=obj.pk))
+            return self.action_call(ar, ba, status)
 
     def href_to(self, ar, obj, text=None):
         h = self.obj2url(ar, obj)
@@ -490,19 +508,38 @@ class HtmlRenderer(Renderer):
         """
         return self.not_implemented_js
 
+    def get_permalink(self, ar, ba, obj, **apv):
+        # similar to ar2js() but to be used when permalink_uris is True
+        # kwargs.update(self.get_action_params(ar, ba, None, **kwargs))
+        kwargs = dict()
+        if ba.action.parameters:
+            fv = ba.action.params_layout.params_store.pv2list(ar, apv)
+            kwargs[constants.URL_PARAM_FIELD_VALUES] = fv
+
+        kwargs[constants.URL_PARAM_ACTION_NAME] = ba.action.action_name
+        arguments = ["api", str(ba.actor.app_label), str(ba.actor.__name__), str(obj.pk)]
+        if ar.hash_router:
+            arguments.insert(0, '#')
+        return settings.SITE.buildurl(*arguments, **kwargs)
+
     def row_action_button(
             self, obj, ar, ba, label=None, title=None, request_kwargs={},
-            **kw):
+            **button_attrs):
         """
         Return a HTML fragment that displays a button-like link
         which runs the bound action `ba` when clicked.
         """
         label = label or ba.get_button_label()
-        request_kwargs.update(selected_rows=[obj])
-        js = self.action_call_on_instance(obj, ar, ba, request_kwargs)
-        uri = self.js2url(js)
+        if ar is not None and ar.permalink_uris:
+            apvs = request_kwargs.get('action_param_values', {})
+            uri = ar.get_permalink(ba, obj, **apvs)  # "20210712"
+        else:
+            # TODO: why put obj to selected_rows and then pass it on?
+            request_kwargs.update(selected_rows=[obj])
+            js = self.action_call_on_instance(obj, ar, ba, request_kwargs)
+            uri = self.js2url(js)
         return self.href_button_action(
-            ba, uri, label, title or ba.action.help_text, **kw)
+            ba, uri, label, title or ba.action.help_text, **button_attrs)
 
     def row_action_button_ar(
             self, obj, ar, label=None, title=None, request_kwargs={},
@@ -666,7 +703,7 @@ class TextRenderer(HtmlRenderer):
             display_mode = ar.actor.display_mode
         # if ar.actor.master is not None and not nosummary:
         if not nosummary:
-            if display_mode == 'summary':
+            if display_mode == constants.DISPLAY_MODE_SUMMARY:
                 s = to_rst(
                     ar.actor.get_table_summary(ar.master_instance, ar),
                     stripped=stripped)
@@ -675,6 +712,16 @@ class TextRenderer(HtmlRenderer):
                 yield s
                 return
 
+        if display_mode == constants.DISPLAY_MODE_CARDS:
+            for row in ar.sliced_data_iterator:
+                txt = ar.get_card_title(row)
+                print(txt)
+                print("=" * len(txt))
+                ar.show_detail(row, display_mode=display_mode)
+                print()
+            # rows = [ar.show_detail]
+            return
+
         fields, headers, widths = ar.get_field_info(column_names)
 
         # if str(ar.actor) == "working.WorkedHours":
@@ -829,8 +876,6 @@ class JsRenderer(HtmlRenderer):
             kw.update(record_id=obj.pk)
         else:
             kw.update(record_id=obj)
-
-
         return kw
 
     def ar2js(self, ar, obj, **status):
