@@ -26,13 +26,13 @@ from lino.core.auth.utils import AnonymousUser
 from lino.core import callbacks
 from lino.core import actions
 
-from .boundaction import BoundAction
-from .signals import on_ui_created, pre_ui_save
-from .diff import ChangeWatcher
-from .utils import getrqdata
-from .utils import obj2unicode
-from .utils import obj2str
-from .exceptions import ChangedAPI
+from lino.core.boundaction import BoundAction
+from lino.core.signals import on_ui_created, pre_ui_save
+from lino.core.diff import ChangeWatcher
+from lino.core.utils import getrqdata
+from lino.core.utils import obj2unicode
+from lino.core.utils import obj2str
+from lino.core.exceptions import ChangedAPI
 
 CATCHED_AJAX_EXCEPTIONS = (Warning, exceptions.ValidationError)
 
@@ -59,9 +59,11 @@ class ValidActionResponses(object):
 
     alert = None
     """
-    True to specify that the message is rather important and should
-    alert and should be presented in a dialog box to be confirmed by
-    the user.
+    Set this to some translatable text to specify that the message is rather
+    important and should alert and should be presented in a dialog box to be
+    confirmed by the user. The text is used as the title of the alert box.  If
+    you specify `True`, then Lino uses a default text like "Alert" or "Warning"
+    (depending on context).
     """
     alert_eval_js = None
     """
@@ -80,6 +82,7 @@ class ValidActionResponses(object):
     no_data_text = None
     title = None
     """The dynamic title to give to the window or component which shows this response.
+    TODO: is this still being used?
     """
 
     count = None
@@ -225,6 +228,14 @@ class BaseRequest(object):
     See :ref:`permalink_uris` for details and test coverage.
     """
 
+    hash_router = False
+    """
+
+    Used in permalink URIs creation. Set this to `True` if the front_end root
+    has an hash router. Ex: `lino_react`.
+
+    """
+
     master_instance = None
     """
     The database object which acts as master. This is `None` for master
@@ -245,7 +256,7 @@ class BaseRequest(object):
 
     _status = None  # cache when get_status() is called multiple times
 
-    def __init__(self, request=None, parent=None,
+    def __init__(self, request=None, parent=None, hash_router=None,
                  is_on_main_actor=True, permalink_uris=None, **kw):
         self.response = dict()
 
@@ -256,6 +267,8 @@ class BaseRequest(object):
             kw = self.parse_req(request, self.rqdata, **kw)
             if permalink_uris is None:
                 permalink_uris = False  # todo: which default value?
+            if hash_router is None:
+                hash_router = False
         elif parent is not None:
             # if parent.actor is None:
             # 20190926 we want to have javascript extjs links in dasboard
@@ -283,9 +296,12 @@ class BaseRequest(object):
             # is_on_main_actor = False
             if permalink_uris is None:
                 permalink_uris = parent.permalink_uris
+            if hash_router is None:
+                hash_router = parent.hash_router
 
         self.is_on_main_actor = is_on_main_actor
         self.permalink_uris = permalink_uris
+        self.hash_router = hash_router
         self.setup(**kw)
 
     def setup(self,
@@ -715,9 +731,15 @@ class BaseRequest(object):
     # def parse_memo(self, html):
     #     return self.renderer.parse_memo(html, ar=self)
 
+    def show_detail(self, *args, **kwargs):
+        return self.renderer.show_detail(self, *args, **kwargs)
+
     def get_detail_url(self, *args, **kwargs):
         return self.renderer.get_detail_url(self, *args, **kwargs)
 
+    def get_permalink(self, *args, **kwargs):
+        return self.renderer.get_permalink(self, *args, **kwargs)
+
     def set_callback(self, *args, **kw):
         return callbacks.set_callback(self, *args, **kw)
 
@@ -727,6 +749,9 @@ class BaseRequest(object):
     def goto_instance(self, *args, **kwargs):
         return self.renderer.goto_instance(self, *args, **kwargs)
 
+    def ar2js(self, *args, **kwargs):
+        return self.renderer.ar2js(self, *args, **kwargs)
+
     def goto_pk(self, pk, text, **kwargs):
         """Navigate to the record with the specified primary key.
 
@@ -910,7 +935,12 @@ class BaseRequest(object):
                     nosummary=nosummary, stripped=stripped,
                     show_links=show_links, display_mode=display_mode)
             elif isinstance(ar.bound_action.action, actions.ShowDetail):
-                return ar.renderer.show_detail(ar)
+                if len(ar.selected_rows) > 0:
+                    obj = ar.selected_rows[0]
+                else:
+                    obj = None
+                    # e.g. rt.show('system.Dashboard')  20210910
+                return ar.renderer.show_detail(ar, obj)
             else:
                 print("Cannot show", ar.bound_action.action)
 
@@ -1041,7 +1071,8 @@ class BaseRequest(object):
 
     def row_action_button(self, obj, ba, *args, **kwargs):
         return self.renderer.row_action_button(
-            obj, None, ba, *args, **kwargs)
+            obj, self, ba, *args, **kwargs)
+            # 20210715 dangerous change: replaced None by self in above line
 
     def row_action_button_ar(self, obj, *args, **kw):
         """Return an HTML element with a button for running this action
