@@ -1062,10 +1062,10 @@ class ParameterStore(BaseStore):
         #     print("20200423", d)
         return d
 
-    def pv2list(self, ar, pv, **d):  # new since 20140930
+    def pv2list(self, ar, apv):  # new since 20140930
         l = []
         for fld in self.param_fields:
-            v = pv.get(fld.name, None)
+            v = apv.get(fld.name, None)
             l.append(v)
         return l
 
