@@ -749,24 +749,6 @@ def lazy_format(tpl, *args, **kwargs):
         return tpl.format(*args, **kwargs)
     return lazy(f, str)()
 
-simplify_parts = set(
-    ['models', 'desktop', 'ui', 'choicelists', 'actions', 'mixins'])
-
-def simplify_name(name):
-    """
-    Simplify the given full Python name.
-
-    Removes any part 'models', 'desktop', 'ui', 'choicelists',
-    'mixins' or 'actions' from the name.
-
-    This is used when we want to ignore where exactly a model or table
-    or action is being defined within its plugin.
-    """
-    parts = name.split('.')
-    for e in simplify_parts:
-        if e in parts:
-            parts.remove(e)
-    return '.'.join(parts)
 
 def resolve_fields_list(model, k, collection_type=tuple, default=None):
     qsf = getattr(model, k)
