@@ -1,18 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2015 Luc Saffre
-"""
-Database models for `lino.modlib.bootstrap3`.
-
-.. autosummary::
-
-"""
+# Copyright 2014-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
 from django.conf import settings
 from lino.core.tables import AbstractTable
-from django.utils.translation import ugettext_lazy as _
+from lino.core.roles import Expert
 
-from lino.api import dd
+from lino.api import dd, _
 
 
 class ShowAsHtml(dd.Action):
@@ -24,6 +19,7 @@ class ShowAsHtml(dd.Action):
     default_format = 'ajax'
     preprocessor = "Lino.get_current_grid_config"
     callable_from = "t"
+    required_roles = dd.login_required(Expert)
 
     def run_from_ui(self, ar, **kw):
         url = dd.plugins.bootstrap3.renderer.get_request_url(ar)
