@@ -61,10 +61,19 @@ class Comment(CreatedModified, UserAuthored, Controllable,
 
     my_emotion = MyEmotionField()
 
+    def disabled_fields(self, ar):
+        s = super().disabled_fields(ar)
+        if ar.get_user().is_anonymous:
+            s.add('my_emotion')
+        return s
+
     def get_my_emotion(self, ar):
         if ar is None:
             return
-        mr = rt.models.comments.Reaction.objects.filter(user=ar.get_user(), comment=self).first()
+        u = ar.get_user()
+        if u.is_anonymous:
+            return
+        mr = rt.models.comments.Reaction.objects.filter(user=u, comment=self).first()
         if mr:
             return mr.emotion
 
@@ -183,18 +192,18 @@ class Comment(CreatedModified, UserAuthored, Controllable,
             qs = pv.observed_event.add_filter(qs, pv)
         return qs
 
-    @dd.htmlbox()
-    def card_summary(self, ar):
-        if not ar:
-            return ""
-        # header = ar.actor.get_comment_header(self, ar) if ar else ""
-        body = ar.parse_memo(self.body)
-        # for e in lxml.html.fragments_fromstring(self.body_short_preview):  # , parser=cls.html_parser)
-        #     html += tostring(e)
-
-        return "<div><p>{}</p></div>".format(
-            # header,
-            body)
+    # @dd.htmlbox()
+    # def card_summary(self, ar):
+    #     if not ar:
+    #         return ""
+    #     # header = ar.actor.get_comment_header(self, ar) if ar else ""
+    #     body = ar.parse_memo(self.body)
+    #     # for e in lxml.html.fragments_fromstring(self.body_short_preview):  # , parser=cls.html_parser)
+    #     #     html += tostring(e)
+    #
+    #     return "<div><p>{}</p></div>".format(
+    #         # header,
+    #         body)
 
     # def summary_row(o, ar):
 
