@@ -12,7 +12,7 @@ from etgen.html import E, tostring
 import lxml
 # from lino.utils.soup import truncate_comment
 from lino import mixins
-from lino.core.constants import CHOICES_BLANK_FILTER_VALUE
+from lino.core.constants import CHOICES_BLANK_FILTER_VALUE, DISPLAY_MODE_STORY
 from lino.core.utils import qs2summary
 from lino.core.gfks import gfk2lookup
 from .roles import CommentsReader, CommentsUser, CommentsStaff
@@ -82,10 +82,10 @@ class Comments(dd.Table):
     detail_layout = "comments.CommentDetail"
 
     card_layout = dd.Panel("""
-    reply_to owner owner_type owner_id
+    # reply_to owner owner_type owner_id
     # comment_type
-    body
-    private
+    body_short_preview
+    # private
     """, label=_("Cards"))
 
     # html_parser = etree.HTMLParser()
@@ -134,7 +134,7 @@ class Comments(dd.Table):
             reply_to=comment, **gfk2lookup(
                 comment.__class__.owner, comment.owner))
         # if ar.get_user().is_authenticated:
-        if sar.has_permission():
+        if sar.get_permission():
             btn = sar.ar2button(None, _(" Reply "), icon_name=None)
             # btn.set("style", "padding-left:10px")
             ch += [" [", btn, "]"]
@@ -197,16 +197,17 @@ class CommentsByX(Comments):
     order_by = ["-created"]
     # order_by = ["-modified"]
     display_mode = "summary"
-    card_layout = dd.DetailLayout("""
-    card_summary
-    RepliesByComment
-    """)
+    # card_layout = dd.DetailLayout("""
+    # card_summary
+    # RepliesByComment
+    # """)
 
     @classmethod
     def get_card_title(self, ar, obj):
         """Overrides the default behaviour
         """
-        return ar.actor.get_comment_header(obj, ar)
+        return _("Created {created} by {user}").format(
+            created=naturaltime(obj.created), user=str(obj.user))
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
@@ -388,8 +389,10 @@ class CommentsByRFC(CommentsByX):
     @classmethod
     def get_main_card(self, ar):
         ticket_obj = ar.master_instance
+        if ticket_obj is None:
+            return None
         sar = self.request_from(ar, master_instance=ticket_obj)
-        html=ticket_obj.get_rfc_description(ar)
+        html = ticket_obj.get_rfc_description(ar)
         sar = self.insert_action.request_from(sar)
         if sar.get_permission():
             btn = sar.ar2button(None, _("Write comment"), icon_name=None)
@@ -452,7 +455,7 @@ class RepliesByComment(CommentsByX):
     master_key = 'reply_to'
     # display_mode = "list"
     stay_in_grid = True
-    borderless_list_mode = True
+    display_mode = DISPLAY_MODE_STORY
     # title = _("Replies")
     label = _("Replies")
     simple_slavegrid_header = True
