@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds the default Lino user interface based on ExtJS.
 
@@ -31,7 +31,7 @@ from __future__ import unicode_literals
 from __future__ import print_function
 
 from lino.api.ad import Plugin
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 # raise Exception("20160528")
 
@@ -217,7 +217,9 @@ class Plugin(Plugin):
     def get_patterns(self):
 
         from django.conf import settings
-        from django.conf.urls import url  # patterns
+        # django.conf.urls.url() is deprecated in favor of django.urls.re_path
+        # from django.conf.urls import url  # patterns
+        from django.urls import re_path as url
         from . import views
 
         self.renderer.build_site_cache()
@@ -228,9 +230,10 @@ class Plugin(Plugin):
             # url(rx + '/?$', views.AdminIndex.as_view()),
             url(rx + '$', views.AdminIndex.as_view()),
             url(rx + r'api/main_html$', views.MainHtml.as_view()),
+            url('service-worker.js', views.SWView.as_view()),
             # url(rx + r'auth$', views.Authenticate.as_view()),
-            url(rx + r'grid_config/(?P<app_label>\w+)/(?P<actor>\w+)$',
-                views.GridConfig.as_view()),
+            # url(rx + r'grid_config/(?P<app_label>\w+)/(?P<actor>\w+)$',
+            #     views.GridConfig.as_view()),
             url(rx + r'api/(?P<app_label>\w+)/(?P<actor>\w+)$',
                 views.ApiList.as_view()),
             url(rx + r'api/(?P<app_label>\w+)/(?P<actor>\w+)/(?P<pk>.+)$',
