@@ -32,6 +32,7 @@ from os import environ
 from django import http
 from django.db import models
 from django.conf import settings
+from django.core.cache import cache
 from django.core.exceptions import PermissionDenied
 from django.views.generic import View
 from django.views.generic.base import TemplateView
@@ -141,9 +142,15 @@ def test_version_mismatch(request):
     if environ.get("PYCHARM_HOSTED", False):
         return {}
     lv = request.GET.get(constants.URL_PARAM_LINO_VERSION)
-    if lv is None or float(lv) == settings.SITE.kernel.code_mtime:
+    if (lv is None
+    or (settings.SITE.never_build_site_cache
+    and settings.SITE.kernel.lino_version == lv)
+    or float(lv) == settings.SITE.kernel.code_mtime):
         return {}
     # print("20201217", lv, settings.SITE.kernel.code_mtime)
+    cache.clear()
+    if settings.SITE.kernel.default_ui.verbose_name == 'React':
+        return dict(version_mismatch=True)
     return dict(alert=_("Version mismatch"),
                 message=_("Your browser is using a previous version of the site, press OK to reload the site"),
                 alert_eval_js="window.location.reload(true);")
@@ -356,6 +363,7 @@ class ApiElement(View):
 
         fmt = request.GET.get(
             constants.URL_PARAM_FORMAT, ba.action.default_format)
+
         if ba.action.opens_a_window:
             if fmt == constants.URL_FORMAT_JSON:
                 if pk == '-99999':
@@ -369,7 +377,12 @@ class ApiElement(View):
                         success=False, message=NOT_FOUND % (rpt, pk))
                 else:
                     datarec = ar.elem2rec_detailed(elem)
-                datarec.update(test_version_mismatch(request))
+                vm = test_version_mismatch(request)
+                if vm:
+                    datarec.update(vm)
+                    resp = json_response(datarec)
+                    resp['Clear-Site-Data'] = '"cache", "storage", "executionContexts"'
+                    return resp
                 return json_response(datarec)
 
             after_show = ar.get_status(record_id=pk)
@@ -478,7 +491,12 @@ class ApiList(View):
                 kw.update(
                     param_values=ar.actor.params_layout.params_store.pv2dict(
                         ar, ar.param_values))
-            kw.update(test_version_mismatch(request))
+            vm = test_version_mismatch(request)
+            if vm:
+                kw.update(vm)
+                resp = json_response(kw)
+                resp['Clear-Site-Data'] = '"cache", "storage", "executionContexts"'
+                return resp
             return json_response(kw)
 
         if fmt == constants.URL_FORMAT_HTML:
