@@ -1,10 +1,10 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2010-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django import VERSION
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.db.utils import DatabaseError
 from django.core.exceptions import FieldDoesNotExist
 from django.contrib.contenttypes.models import ContentType, models
@@ -61,7 +61,6 @@ class ContentTypes(dd.Table):
         return E.p(*join_elems(chunks, sep=', '))
 
 
-
 class HelpText(dd.Model):
     class Meta(object):
         app_label = 'gfks'
