@@ -20,28 +20,29 @@ from lino.modlib.checkdata.choicelists import Checker
 from lino.api import _
 
 
-def truncate_comment(html_str, max_p_len=None):
+def truncate_comment(html_str, max_p_len=300):
     html_str = html_str.strip()  # remove leading or trailing newlines
     if not html_str.startswith('<'):
-        # it's plain text without html tags
-        ps = html_str.split('\n\n', 1)
-        txt = ps[0]
-        if max_p_len is not None and len(txt) > max_p_len:
-            txt = txt[:max_p_len] + "..."
-        elif len(ps) > 1:
-            txt = txt + " (...)"
+        if len(html_str) > max_p_len:
+            txt = html_str[:max_p_len] + "..."
+        else:
+            txt = html_str
         return txt
     soup = BeautifulSoup(html_str, "html.parser")
-    ps = soup.find_all(["p", "h1", "h2", "h3", "h4", "h5", "h6", "h7", "h8", "h9"])
+    ps = soup.find_all(["p", "h1", "h2", "h3", "h4", "h5", "h6", "h7", "h8", "h9", "pre"])
     if len(ps) > 0:
-        txt = ps[0].text
-        if max_p_len is not None and len(txt) > max_p_len:
-            txt = txt[:max_p_len] + "..."
-        elif len(ps) > 1:
-            txt = txt + " (...)"
+        txt = ""
+        for p in ps:
+            text = p.text
+            # TODO: something like for w in p.text.split() but using regex
+            if len(txt) + len(text) > max_p_len:
+                txt += text
+                txt = txt[:max_p_len]
+                txt += "..."
+                break
+            else:
+                txt += text + "\n\n"
         return txt
-        # ps[0].string = (txt)
-        # return six.text_type(ps[0])
     return html_str
 
 
@@ -83,8 +84,8 @@ def parse_previews(source, ar=None):
         ar = BaseRequest(renderer=front_end.renderer)
         # print("20190926 using BaseRequest with front end {}".format(front_end))
     parse = settings.SITE.plugins.memo.parser.parse
-    short = parse(truncate_comment(source), ar)
     full = parse(source, ar)
+    short = truncate_comment(full)
     return (short, full)
 
 class BasePreviewable(Model):
