@@ -1,8 +1,9 @@
-# Copyright 2016-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2016-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
+import multiprocessing as mp
 from etgen.html import E, tostring
-
+from django.conf import settings
 from lino.api import dd, rt, _
 
 PUBLIC_GROUP = 'all_users_channel'
@@ -89,8 +90,12 @@ class ChangeNotifier(dd.Model):
                 if not subject:
                     return None
                 return (subject, self.get_change_body(ar, cw))
-            # owner = self.get_change_owner()
-            # rt.models.notify.Message.emit_notification(
-            #     ar, owner, mt, msg, self.get_change_observers(ar))
-            rt.models.notify.Message.emit_notification(
-                ar, self, mt, msg, self.get_change_observers(ar))
+            owner = self.get_change_owner()
+            if settings.SITE.use_multiprocessing:
+                proc = mp.Process(
+                    target=rt.models.notify.Message.emit_notification,
+                    args=(ar, owner, mt, msg, self.get_change_observers(ar)))
+                proc.start()
+            else:
+                rt.models.notify.Message.emit_notification(
+                    ar, owner, mt, msg, self.get_change_observers(ar))
