@@ -9,7 +9,7 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_protect
 
 from lino.core import auth
-from lino.core.requests import BaseRequest
+from lino.core.requests import BaseRequest, ActionRequest
 
 from django.shortcuts import redirect
 
@@ -19,7 +19,14 @@ class Element(View):
     publisher_model = None
 
     def get(self, request, pk=None):
-        ar = BaseRequest(request=request, renderer=settings.SITE.kernel.default_renderer, permalink_uris=True)
+        rnd = settings.SITE.kernel.default_renderer
+
+        kw = dict(actor=self.publisher_model.get_default_table(),
+            request=request, renderer=rnd, permalink_uris=True)
+        if rnd.front_end.media_name == 'react':
+            kw.update(hash_router=True)
+
+        ar = ActionRequest(**kw)
         obj = self.publisher_model.objects.get(id=pk) if pk is not None else None
         return obj.get_publisher_response(ar)
 
