@@ -22,7 +22,19 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino.modlib.system']
     # online_registration = False
     active_sessions_limit = -1
-    use_verify = False
+
+    allow_online_registration = False
+    """Whether to allow users to register online."""
+    verification_code_expires = 5
+    """
+    This value is in minutes. Used to invalidate a user verification code after
+    the elapsed minutes.
+    """
+    user_type_new = 'user'
+    """The default user_type for an unverified user."""
+    user_type_verified = 'user'
+    """The default user_type for a verified user."""
+
     # partner_model = 'contacts.Person'
     partner_model = 'contacts.Partner'
 
@@ -34,12 +46,25 @@ class Plugin(ad.Plugin):
         #         return
         self.partner_model = site.models.resolve(self.partner_model)
 
+    def unused_on_plugins_loaded(self, site):
+        if self.allow_online_registration:
+            # If you use gmail smtp to send email.
+            # See: https://support.google.com/mail/answer/7126229?visit_id=1-636656345878819046-1400238651&rd=1#cantsignin&zippy=%2Ci-cant-sign-in-to-my-email-client
+            # For this setup you will have to allow less secure app access from
+            # your google accounts settings: https://myaccount.google.com/lesssecureapps
+            site.update_settings(
+                EMAIL_HOST='smtp.gmail.com',
+                EMAIL_PORT=587, # For TLS | use 465 for SSL
+                EMAIL_HOST_USER='username@gmail.com',
+                EMAIL_HOST_PASSWORD='*********',
+                EMAIL_USE_TLS=True
+            )
+
     def on_init(self):
         super(Plugin, self).on_init()
         self.site.set_user_model('users.User')
 
 
-
     def setup_config_menu(self, site, user_type, m):
         g = site.plugins.system
         m = m.add_menu(g.app_label, g.verbose_name)
