@@ -2,9 +2,11 @@
 # Copyright 2011-2020 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+import datetime
 from django.db import models
 from django.conf import settings
 from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
+from django.utils import timezone
 
 from lino.api import dd, rt, _
 from etgen.html import E
@@ -18,7 +20,7 @@ from lino.mixins import DateRange
 from .choicelists import UserTypes
 from .mixins import UserAuthored  #, TimezoneHolder
 from .actions import ChangePassword, SignOut, VerifyUser, CheckedSubmitInsert
-from .actions import SendWelcomeMail
+from .actions import SendWelcomeMail, SignIn, CreateAccount
 from .actions import MySettings
 # from .actions import SignIn
 from lino.core.auth.utils import AnonymousUser
@@ -82,6 +84,7 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
     hidden_columns = 'password remarks'
     # authenticated = True
     quick_search_fields = 'username user_type first_name last_name remarks'
+    allow_merge_action = True
 
     # seems that Django doesn't like nullable username
     # username = dd.NullCharField(_('Username'), max_length=30, unique=True)
@@ -95,12 +98,14 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
                 blank=True, null=True,
                 related_name='users_by_partner')
 
-    if dd.plugins.users.use_verify:
+    if dd.plugins.users.allow_online_registration:
         verification_code = models.CharField(max_length=200, blank=True)
+        verification_code_sent_on = models.DateTimeField(null=True, blank=True)
         verify = VerifyUser()
     else:
         verify = None
         verification_code = dd.DummyField()
+        verification_code_sent_on = dd.DummyField()
 
     if settings.USE_TZ:
         time_zone = TimeZones.field(default='default')
@@ -129,13 +134,20 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
         return True
 
     def is_verified(self):
-        if dd.plugins.users.use_verify:
+        if dd.plugins.users.allow_online_registration:
             return not self.verification_code
         return False
 
     def mark_verified(self):
         self.verification_code = ''
 
+    def is_verification_code_expired(self):
+        if self.verification_code_sent_on is None:
+            return False
+        return (self.verification_code_sent_on + datetime.timedelta(
+            minutes=dd.plugins.users.verification_code_expires
+        ) < timezone.now())
+
     def get_as_user(self):
         """
         Overrides :meth:`lino_xl.lib.contacts.Partner.get_as_user`.
@@ -201,6 +213,8 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
             rv.add('user_type')
             rv.add('partner')
             rv.add('send_email')
+            # merging two users is only for SiteAdmin, even when you are Expert
+            rv.add('merge_row')
             if user != self:
                 rv.add('change_password')
         return rv
@@ -250,8 +264,9 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
         return super(User, self).on_create(ar)
 
     def email_changed(self, ar):
-        if self.email and dd.plugins.users.use_verify:
+        if self.email and dd.plugins.users.allow_online_registration:
             self.verification_code = id_generator(12)
+            self.verification_code_sent_on = timezone.now()
 
     def get_received_mandates(self):
         #~ return [ [u.id,_("as %s")%u] for u in self.__class__.objects.all()]
@@ -265,6 +280,8 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
 
     def get_welcome_email_body(self, ar):
         template = rt.get_template('users/welcome_email.eml')
+        # sar = ar.spawn_request(permalink_uris=True)
+        ar.permalink_uris = True
         context = self.get_printable_context(ar)
         # dict(obj=self, E=E, rt=rt)
         return template.render(**context)
@@ -273,7 +290,7 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
         pv = dict(username=self.username)
         if settings.SITE.is_demo_site:
             pv.update(password='1234')
-        btn = rt.models.users.UsersOverview.get_action_by_name('sign_in')
+        btn = rt.models.about.About.get_action_by_name('sign_in')
         # print btn.get_row_permission(ar, None, None)
         btn = btn.request(
             action_param_values=pv,
@@ -396,6 +413,11 @@ class Permission(dd.Model):
         abstract = True
 
 
+from lino.modlib.about.models import About
+About.sign_in = SignIn()
+if dd.plugins.users.allow_online_registration:
+    About.create_account = CreateAccount()
+
 @dd.receiver(dd.post_startup)
 def setup_memo_commands(sender=None, **kwargs):
     # See :doc:`/specs/memo`
