@@ -7,7 +7,7 @@ import sys
 
 SETUP_INFO = dict(
     name='lino',
-    version='21.6.3',
+    version='21.9.1',
     description="A framework for writing desktop-like sustainably free "
                 "web applications using Django and ExtJS or React",
     license='COPYING',
@@ -36,7 +36,7 @@ install_requires.append('Sphinx')  # lino.utils.restify
 install_requires.append('docutils')  # lino.modlib.memo.mixins
 install_requires.append('beautifulsoup4')  # lino.modlib.memo.mixins
 # install_requires.append('reportlab')
-install_requires.append('weasyprint')
+install_requires.append('weasyprint<=52')
 # install_requires.append('zodb')
 install_requires.append('DateTime')
 # install_requires.append('appy@svn+https://svn.forge.pallavi.be/appy-dev/dev1')
@@ -125,6 +125,9 @@ lino.modlib.extjs
 lino.modlib.forms
 lino.modlib.gfks
 lino.modlib.gfks.fixtures
+lino.modlib.help
+lino.modlib.help.management
+lino.modlib.help.management.commands
 lino.modlib.ipdict
 lino.modlib.jinja
 lino.modlib.jinja.management
