@@ -829,10 +829,22 @@ def get_client_ip_address(request):
     return ip or "(unknown)"  # see ticket #2605
 
 
-class AsynchronousValue:
-    def __init__(self, field, obj):
-        self.field = field
-        self.obj = obj
+class DelayedValue:
+    def __init__(self, ar, fieldname, obj):
+        if fieldname is None:
+            raise Exception("20210617 {}".format(field))
+        a = ar.actor
+        self.url = "values/{}/{}/{}".format(
+            str(a).replace(".","/"), obj.pk, fieldname)
+        # print(self, self.url)
+        # self.field = field
+        # self.obj = obj
+
+    def get_url(self):
+        return self.url
+
+    def __repr__(self):
+        return "DelayedValue({})".format(self.url)
 
 
 def _test():
