@@ -26,7 +26,7 @@ def codefiles(pattern='*'):
     """
     #~ exp = re.compile(pattern, flags)
 
-    for name, mod in list(sys.modules.items()):
+    for name, mod in sys.modules.items():
         #~ if name == 'lino.extjs' and pattern == '*':
             #~ logger.info("20130801 %r -> %r", name,mod.__file__)
         if fnmatch.fnmatch(name, pattern):
